@@ -1,5 +1,43 @@
-""" A set of descriptors that document intended types for attributes on
-classes and implement convenience behaviors like default values, etc.
+""" Properties are objects that can be assigned as class level
+attributes on Bokeh models, to provide automatic serialization
+and validation.
+
+For example, the following defines a model that has integer,
+string, and list[float] properties::
+
+    class Model(HasProps):
+        foo = Int
+        bar = String
+        baz = List(Float)
+
+The properties of this class can be initialized by specifying
+keyword arguments to the initializer::
+
+    m = Model(foo=10, bar="a str", baz=[1,2,3,4])
+
+But also by setting the attributes on an instance::
+
+    m.foo = 20
+
+Attempts to set a property to a value of the wrong type will
+result in a ``ValueError`` exception::
+
+    >>> m.foo = 2.3
+    Traceback (most recent call last):
+      File "<stdin>", line 1, in <module>
+      File "/Users/bryan/work/bokeh/bokeh/properties.py", line 585, in __setattr__
+        super(HasProps, self).__setattr__(name, value)
+      File "/Users/bryan/work/bokeh/bokeh/properties.py", line 159, in __set__
+        raise e
+      File "/Users/bryan/work/bokeh/bokeh/properties.py", line 152, in __set__
+        self.validate(value)
+      File "/Users/bryan/work/bokeh/bokeh/properties.py", line 707, in validate
+        (nice_join([ cls.__name__ for cls in self._underlying_type ]), value, type(value).__name__))
+    ValueError: expected a value of type int8, int16, int32, int64 or int, got 2.3 of type float
+
+Additionally, properties know how to serialize themselves,
+to be understood by BokehJS.
+
 """
 from __future__ import absolute_import, print_function
 
@@ -8,6 +46,7 @@ import types
 import difflib
 import datetime
 import dateutil.parser
+import collections
 from importlib import import_module
 from copy import copy
 import inspect
@@ -18,7 +57,7 @@ from six import integer_types, string_types, add_metaclass, iteritems
 import numpy as np
 
 from . import enums, colors
-from .utils import nice_join
+from .util.string import nice_join
 
 bokeh_integer_types = (np.int8, np.int16, np.int32, np.int64) + integer_types
 
@@ -40,7 +79,7 @@ class Property(object):
             self.validate(default)
 
         self._default = default
-        self.help = help
+        self.__doc__ = help
         self.alternatives = []
 
         # This gets set by the class decorator at class creation time
@@ -219,11 +258,15 @@ class DataSpec(Property):
         """
         # Don't use .name because the HasProps metaclass uses that to
         # store the attribute name on this descriptor.
-        self.field = field
+        if field is None or isinstance(field, string_types):
+            self.field = field
+        else:
+            raise ValueError("'field' must be a string or None, got %r" % field)
+
         self.units = units
         self._default = default
         self.min_value = min_value
-        self.help = help
+        self.__doc__ = help
 
     @classmethod
     def autocreate(cls, name=None):
@@ -315,7 +358,7 @@ class ColorSpec(DataSpec):
     and indicating a field name to look for on the datasource:
 
     >>> class Bar(HasProps):
-    ...     col = ColorSpec("green")
+    ...     col = ColorSpec(default="green")
     ...     col2 = ColorSpec("colorfield")
 
     >>> b = Bar()
@@ -340,7 +383,7 @@ class ColorSpec(DataSpec):
         self.field = field
         self._default = default
         self.value = value
-        self.help = help
+        self.__doc__ = help
 
         if field_or_value is not None:
             if self.isconst(field_or_value):
@@ -348,6 +391,9 @@ class ColorSpec(DataSpec):
             else:
                 self.field = field_or_value
 
+        if not (self.field is None or isinstance(self.field, string_types)):
+            raise ValueError("'field' must be a string or None, got %r" % self.field)
+
         # We need to distinguish if the user ever explicitly sets the attribute; if
         # they explicitly set it to None, we should pass on None in the dict.
         self._isset = False
@@ -441,13 +487,15 @@ class ColorSpec(DataSpec):
         return "ColorSpec(field=%r)" % self.field
 
 class Include(object):
-    ''' Include other properties from mixin Models, with a given prefix. '''
+    """ Include other properties from mixin Models, with a given prefix. """
 
-    def __init__(self, delegate):
+    def __init__(self, delegate, help="", use_prefix=True):
         if not (isinstance(delegate, type) and issubclass(delegate, HasProps)):
             raise ValueError("expected a subclass of HasProps, got %r" % delegate)
 
         self.delegate = delegate
+        self.help = help
+        self.use_prefix = use_prefix
 
 class MetaHasProps(type):
     def __new__(cls, class_name, bases, class_dict):
@@ -463,7 +511,10 @@ class MetaHasProps(type):
                 continue
 
             delegate = prop.delegate
-            prefix = re.sub("_props$", "", name) + "_"
+            if prop.use_prefix:
+                prefix = re.sub("_props$", "", name) + "_"
+            else:
+                prefix = ""
 
             for subpropname in delegate.class_properties(withbases=False):
                 fullpropname = prefix + subpropname
@@ -473,7 +524,15 @@ class MetaHasProps(type):
                     # so two properties don't write to the same hidden variable
                     # inside the instance.
                     subprop = copy(subprop)
-                includes[fullpropname] = subprop
+                if "%s" in prop.help:
+                    doc = prop.help % subpropname.replace('_', ' ')
+                else:
+                    doc = prop.help
+                try:
+                    includes[fullpropname] = subprop(help=doc)
+                except TypeError:
+                    includes[fullpropname] = subprop
+                    subprop.__doc__ = doc
             # Remove the name of the Include attribute itself
             removes.add(name)
 
@@ -647,6 +706,11 @@ class HasProps(object):
             print("%s%s: %r" % ("  "*indent, key, value))
 
 class PrimitiveProperty(Property):
+    """ A base class for simple property types. Subclasses should
+    define a class attribute ``_underlying_type`` that is a tuple
+    of acceptable type values for the property.
+
+    """
 
     _underlying_type = None
 
@@ -665,29 +729,29 @@ class PrimitiveProperty(Property):
             raise DeserializationError("%s expected %s, got %s" % (self, expected, json))
 
 class Bool(PrimitiveProperty):
-    ''' Boolean type property. '''
+    """ Boolean type property. """
     _underlying_type = (bool,)
 
 class Int(PrimitiveProperty):
-    ''' Signed integer type property. '''
+    """ Signed integer type property. """
     _underlying_type = bokeh_integer_types
 
 class Float(PrimitiveProperty):
-    ''' Floating point type property. '''
+    """ Floating point type property. """
     _underlying_type = (float, ) + bokeh_integer_types
 
 class Complex(PrimitiveProperty):
-    ''' Complex floating point type property. '''
+    """ Complex floating point type property. """
     _underlying_type = (complex, float) + bokeh_integer_types
 
 class String(PrimitiveProperty):
-    ''' String type property. '''
+    """ String type property. """
     _underlying_type = string_types
 
 class Regex(String):
-    ''' Regex type property validates that text values match the
+    """ Regex type property validates that text values match the
     given regular expression.
-    '''
+    """
     def __init__(self, regex, default=None, help=None):
         self.regex = re.compile(regex)
         super(Regex, self).__init__(default=default, help=help)
@@ -702,7 +766,10 @@ class Regex(String):
         return "%s(%r)" % (self.__class__.__name__, self.regex.pattern)
 
 class ParameterizedProperty(Property):
-    """ Base class for Properties that have type parameters, e.g. `List(String)`. """
+    """ Base class for Properties that have type parameters, e.g.
+    ``List(String)``.
+
+    """
 
     @staticmethod
     def _validate_type_param(type_param):
@@ -725,34 +792,33 @@ class ParameterizedProperty(Property):
         return any(type_param.has_ref for type_param in self.type_params)
 
 class ContainerProperty(ParameterizedProperty):
-    ''' Base class for Container-like type properties. '''
-    # Base class for container-like things; this helps the auto-serialization
-    # and attribute change detection code
+    """ Base class for Container-like type properties. """
     pass
 
-class List(ContainerProperty):
-    """ If a default value is passed in, then a shallow copy of it will be
-    used for each new use of this property.
+class Seq(ContainerProperty):
+    """ Sequence (list, tuple) type property.
 
-    People will also frequently pass in some other kind of property or a
-    class (to indicate a list of instances).  In those cases, we want to
-    just create an empty list
     """
 
-    def __init__(self, item_type, default=[], help=None):
+    def _is_seq(self, value):
+        return isinstance(value, collections.Container) and not isinstance(value, collections.Mapping)
+
+    def _new_instance(self, value):
+        return value
+
+    def __init__(self, item_type, default=None, help=None):
         self.item_type = self._validate_type_param(item_type)
-        super(List, self).__init__(default=default, help=help)
+        super(Seq, self).__init__(default=default, help=help)
 
     @property
     def type_params(self):
         return [self.item_type]
 
     def validate(self, value):
-        super(List, self).validate(value)
+        super(Seq, self).validate(value)
 
         if value is not None:
-            if not (isinstance(value, list) and \
-                    all(self.item_type.is_valid(item) for item in value)):
+            if not (self._is_seq(value) and all(self.item_type.is_valid(item) for item in value)):
                 raise ValueError("expected an element of %s, got %r" % (self, value))
 
     def __str__(self):
@@ -762,13 +828,42 @@ class List(ContainerProperty):
         if json is None:
             return None
         elif isinstance(json, list):
-            return [ self.item_type.from_json(item, models) for item in json ]
+            return self._new_instance([ self.item_type.from_json(item, models) for item in json ])
         else:
             raise DeserializationError("%s expected a list or None, got %s" % (self, json))
 
+class List(Seq):
+    """ Python list type property.
+
+    """
+
+    def __init__(self, item_type, default=[], help=None):
+        # todo: refactor to not use mutable objects as default values.
+        # Left in place for now because we want to allow None to express
+        # opional values. Also in Dict.
+        super(List, self).__init__(item_type, default=default, help=help)
+
+    def _is_seq(self, value):
+        return isinstance(value, list)
+
+class Array(Seq):
+    """ NumPy array type property.
+
+    """
+
+    def _is_seq(self, value):
+        import numpy as np
+        return isinstance(value, np.ndarray)
+
+    def _new_instance(self, value):
+        return np.array(value)
+
 class Dict(ContainerProperty):
-    """ If a default value is passed in, then a shallow copy of it will be
+    """ Python dict type property.
+
+    If a default value is passed in, then a shallow copy of it will be
     used for each new use of this property.
+
     """
 
     def __init__(self, keys_type, values_type, default={}, help=None):
@@ -800,7 +895,7 @@ class Dict(ContainerProperty):
             raise DeserializationError("%s expected a dict or None, got %s" % (self, json))
 
 class Tuple(ContainerProperty):
-    ''' Tuple type property. '''
+    """ Tuple type property. """
     def __init__(self, tp1, tp2, *type_params, **kwargs):
         self._type_params = list(map(self._validate_type_param, (tp1, tp2) + type_params))
         super(Tuple, self).__init__(default=kwargs.get("default"), help=kwargs.get("help"))
@@ -828,29 +923,11 @@ class Tuple(ContainerProperty):
         else:
             raise DeserializationError("%s expected a list or None, got %s" % (self, json))
 
-class Array(ContainerProperty):
-    """ Whatever object is passed in as a default value, np.asarray() is
-    called on it to create a copy for the default value for each use of
-    this property.
-    """
-
-    def __init__(self, item_type, default=None, help=None):
-        self.item_type = self._validate_type_param(item_type)
-        super(Array, self).__init__(default=default, help=help)
-
-    @property
-    def type_params(self):
-        return [self.item_type]
-
-    def validate(self, value):
-        super(Array, self).validate(value)
-        # TODO: implement validation of np.array, etc.
-
 class Instance(Property):
-    ''' Instance type property for referneces to other Models in the object
+    """ Instance type property, for references to other Models in the object
     graph.
 
-    '''
+    """
     def __init__(self, instance_type, default=None, help=None):
         if not isinstance(instance_type, (type,) + string_types):
             raise ValueError("expected a type or string, got %s" % instance_type)
@@ -919,41 +996,41 @@ class This(Property):
 
 # Fake types, ABCs
 class Any(Property):
-    ''' Any type property accepts any values. '''
+    """ Any type property accepts any values. """
     pass
 
 class Function(Property):
-    ''' Function type property. '''
+    """ Function type property. """
     pass
 
 class Event(Property):
-    ''' Event type property. '''
+    """ Event type property. """
     pass
 
-class Range(ParameterizedProperty):
-    ''' Range type property ensures values are between a range. '''
-    def __init__(self, range_type, start, end, default=None, help=None):
-        self.range_type = self._validate_type_param(range_type)
-        self.range_type.validate(start)
-        self.range_type.validate(end)
+class Interval(ParameterizedProperty):
+    ''' Range type property ensures values are contained inside a given interval. '''
+    def __init__(self, interval_type, start, end, default=None, help=None):
+        self.interval_type = self._validate_type_param(interval_type)
+        self.interval_type.validate(start)
+        self.interval_type.validate(end)
         self.start = start
         self.end = end
-        super(Range, self).__init__(default=default, help=help)
+        super(Interval, self).__init__(default=default, help=help)
 
     @property
     def type_params(self):
-        return [self.range_type]
+        return [self.interval_type]
 
     def validate(self, value):
-        super(Range, self).validate(value)
+        super(Interval, self).validate(value)
 
-        if not (value is None or self.range_type.is_valid(value) and value >= self.start and value <= self.end):
-            raise ValueError("expected a value of type %s in range [%s, %s], got %r" % (self.range_type, self.start, self.end, value))
+        if not (value is None or self.interval_type.is_valid(value) and value >= self.start and value <= self.end):
+            raise ValueError("expected a value of type %s in range [%s, %s], got %r" % (self.interval_type, self.start, self.end, value))
 
     def __str__(self):
-        return "%s(%s, %r, %r)" % (self.__class__.__name__, self.range_type, self.start, self.end)
+        return "%s(%s, %r, %r)" % (self.__class__.__name__, self.interval_type, self.start, self.end)
 
-class Byte(Range):
+class Byte(Interval):
     ''' Byte type property. '''
     def __init__(self, default=0, help=None):
         super(Byte, self).__init__(Int, 0, 255, default=default, help=help)
@@ -1062,17 +1139,21 @@ class Align(Property):
     pass
 
 class DashPattern(Either):
-    """
-    This is a property that expresses line dashes.  It can be specified in
-    a variety of forms:
+    """ Dash type property.
 
-    * "solid", "dashed", "dotted", "dotdash", "dashdot"
-    * A tuple or list of integers in the HTML5 Canvas dash specification
-      style: http://www.w3.org/html/wg/drafts/2dcontext/html5_canvas/#dash-list
+    Express patterns that describe line dashes.  ``DashPattern`` values
+    can be specified in a variety of ways:
+
+    * An enum: "solid", "dashed", "dotted", "dotdash", "dashdot"
+    * a tuple or list of integers in the `HTML5 Canvas dash specification style`_.
       Note that if the list of integers has an odd number of elements, then
       it is duplicated, and that duplicated list becomes the new dash list.
 
-    If dash is turned off, then the dash pattern is the empty list [].
+    To indicate that dashing is turned off (solid lines), specify the empty
+    list [].
+
+    .. _HTML5 Canvas dash specification style: http://www.w3.org/html/wg/drafts/2dcontext/html5_canvas/#dash-list
+
     """
 
     _dash_patterns = {
@@ -1084,7 +1165,7 @@ class DashPattern(Either):
     }
 
     def __init__(self, default=[], help=None):
-        types = Enum(enums.DashPattern), Regex(r"^(\d+(\s+\d+)*)?$"), List(Int)
+        types = Enum(enums.DashPattern), Regex(r"^(\d+(\s+\d+)*)?$"), Seq(Int)
         super(DashPattern, self).__init__(*types, default=default, help=help)
 
     def transform(self, value):
@@ -1102,7 +1183,12 @@ class DashPattern(Either):
         return self.__class__.__name__
 
 class Size(Float):
-    """ Equivalent to an unsigned int """
+    """ Size type property.
+
+    .. note::
+        ``Size`` is equivalent to an unsigned int.
+
+    """
     def validate(self, value):
         super(Size, self).validate(value)
 
@@ -1110,8 +1196,11 @@ class Size(Float):
             raise ValueError("expected a non-negative number, got %r" % value)
 
 class Percent(Float):
-    """ Percent is useful for alphas and coverage and extents; more
-    semantically meaningful than Float(0..1)
+    """ Percentage type property.
+
+    Percents are useful for specifying alphas and coverage and extents; more
+    semantically meaningful than Float(0..1).
+
     """
     def validate(self, value):
         super(Percent, self).validate(value)
@@ -1120,11 +1209,13 @@ class Percent(Float):
             raise ValueError("expected a value in range [0, 1], got %r" % value)
 
 class Angle(Float):
-    ''' Angle type property. '''
+    """ Angle type property. """
     pass
 
 class Date(Property):
-    ''' Date (not datetime) type property. '''
+    """ Date (not datetime) type property.
+
+    """
     def __init__(self, default=datetime.date.today(), help=None):
         super(Date, self).__init__(default=default, help=help)
 
@@ -1148,7 +1239,10 @@ class Date(Property):
         return value
 
 class Datetime(Property):
-    ''' Datetime type property. '''
+    """ Datetime type property.
+
+    """
+
     def __init__(self, default=datetime.date.today(), help=None):
         super(Datetime, self).__init__(default=default, help=help)
 
@@ -1173,7 +1267,10 @@ class Datetime(Property):
 
 
 class RelativeDelta(Dict):
-    ''' RelativeDelta type property for time deltas. '''
+    """ RelativeDelta type property for time deltas.
+
+    """
+
     def __init__(self, default={}, help=None):
         keys = Enum("years", "months", "days", "hours", "minutes", "seconds", "microseconds")
         values = Int
