@@ -10,48 +10,64 @@ Attributes:
 
 '''
 
-from os.path import abspath, join, normpath, realpath, relpath, split, splitext
-import sys
+from __future__ import absolute_import
+
 import logging
 logger = logging.getLogger(__name__)
+from os.path import join, relpath, splitext
+import re
 
 import six
 
-from . import __version__, settings
+from . import __version__
+from .settings import settings
+from .util.paths import bokehjsdir
 
-def _server_static_dir():
-    return join(abspath(split(__file__)[0]), "server", "static")
+_DEV_PAT = re.compile(r"^(\d)+\.(\d)+\.(\d)+(dev|rc)")
 
-def _static_path(path):
-    path = normpath(join(_server_static_dir(), path))
-    if sys.platform == 'cygwin': path = realpath(path)
-    return path
 
 def _cdn_base_url():
     return "http://cdn.pydata.org"
 
 def _get_cdn_urls(version=None, minified=True):
     if version is None:
-        version = __version__.split('-')[0]
-    min = ".min" if minified else ""
+        if settings.local_docs_cdn():
+            version = settings.local_docs_cdn()
+        else:
+            version = __version__.split('-')[0]
+
+    # check if we want minified js and css
+    _min = ".min" if minified else ""
+
     base_url = _cdn_base_url()
+    dev_container = 'bokeh/dev'
+    rel_container = 'bokeh/release'
+
+    # check the 'dev' fingerprint
+    container = dev_container if _DEV_PAT.match(version) else rel_container
+
+    if version.endswith(('dev', 'rc')):
+        logger.warn("Getting CDN URL for local dev version will not produce usable URL")
+
     result = {
-        'js_files'  : ['%s/bokeh-%s%s.js' % (base_url, version, min)],
-        'css_files' : ['%s/bokeh-%s%s.css' % (base_url, version, min)],
+        'js_files'  : ['%s/%s/bokeh-%s%s.js' % (base_url, container, version, _min)],
+        'css_files' : ['%s/%s/bokeh-%s%s.css' % (base_url, container, version, _min)],
         'messages'  : [],
     }
+
     if len(__version__.split('-')) > 1:
         result['messages'].append({
             "type" : "warn",
             "text" : "Requesting CDN BokehJS version '%s' from Bokeh development version '%s'. This configuration is unsupported and may not work!" % (version, __version__)
         })
+
     return result
 
 def _get_server_urls(root_url, minified=True):
-    min = ".min" if minified else ""
+    _min = ".min" if minified else ""
     result = {
-        'js_files'  : ['%sbokehjs/static/js/bokeh%s.js' % (root_url,  min)],
-        'css_files' : ['%sbokehjs/static/css/bokeh%s.css' % (root_url,  min)],
+        'js_files'  : ['%sbokehjs/static/js/bokeh%s.js' % (root_url, _min)],
+        'css_files' : ['%sbokehjs/static/css/bokeh%s.css' % (root_url, _min)],
         'messages'  : [],
     }
     return result
@@ -66,11 +82,6 @@ def _inline(paths):
         strings.append(begin + '\n' + middle + '\n' + end)
     return strings
 
-def _file_paths(files, minified):
-    if minified:
-        files = [ root + ".min" + ext for (root, ext) in map(splitext, files) ]
-    return [ _static_path(file) for file in files ]
-
 
 class Resources(object):
     ''' The Resources class encapsulates information relating to loading or
@@ -91,7 +102,7 @@ class Resources(object):
 
         minified (bool, optional) : whether JavaScript and CSS should be minified or not (default: True)
 
-        host (str, optional) : URL and port of Bokeh Server to load resources from
+        root_url (str, optional) : URL and port of Bokeh Server to load resources from
 
             Only valid with ``'server'`` and ``'server-dev'`` modes
 
@@ -161,7 +172,7 @@ class Resources(object):
 
         js_paths = self._js_paths(dev=self.dev, minified=self.minified)
         css_paths = self._css_paths(dev=self.dev, minified=self.minified)
-        base_url = _static_path("js")
+        base_url = join(bokehjsdir(self.dev), "js")
 
         self._js_raw = []
         self._css_raw = []
@@ -230,14 +241,19 @@ class Resources(object):
             return self._root_url
         else:
             return self._default_root_url
+    
+    def _file_paths(self, files, minified):
+        if minified:
+            files = [ root + ".min" + ext for (root, ext) in map(splitext, files) ]
+        return [ join(bokehjsdir(self.dev), file) for file in files ]
 
     def _js_paths(self, minified=True, dev=False):
         files = self._default_js_files_dev if self.dev else self._default_js_files
-        return _file_paths(files, False if dev else minified)
+        return self._file_paths(files, False if dev else minified)
 
     def _css_paths(self, minified=True, dev=False):
         files = self._default_css_files_dev if self.dev else self._default_css_files
-        return _file_paths(files, False if dev else minified)
+        return self._file_paths(files, False if dev else minified)
 
     @property
     def js_wrapper(self):
@@ -245,7 +261,7 @@ class Resources(object):
         def pad(text, n=4):
             return "\n".join([ " "*n + line for line in text.split("\n") ])
 
-        wrapper = lambda code: '$(function() {\n%s\n});' % pad(code)
+        wrapper = lambda code: 'Bokeh.$(function() {\n%s\n});' % pad(code)
 
         if self.dev:
             js_wrapper = lambda code: 'require(["jquery", "main"], function($, Bokeh) {\nBokeh.set_log_level("%s");\n%s\n});' % (self.log_level, pad(wrapper(code)))
