@@ -1,5 +1,13 @@
 (function() {
   require.config({
+    map: {
+      '*': {
+        'jquery': 'jquery-private'
+      },
+      'jquery-private': {
+        'jquery': 'jquery'
+      }
+    },
     paths: {
       jquery: "vendor/jquery-1.11.1/jquery",
       jquery_ui: "vendor/jquery-ui-1.11.2/js",
@@ -11,29 +19,19 @@
       underscore: "vendor/underscore-amd/underscore",
       backbone: "vendor/backbone-amd/backbone",
       bootstrap: "vendor/bootstrap-3.1.1/js",
-      timezone: "vendor/timezone/src/timezone",
-      sprintf: "vendor/sprintf/src/sprintf",
+      timezone: "vendor/timezone-0.0.38/src/timezone",
+      sprintf: "vendor/sprintf-1.0.2/sprintf",
       rbush: "vendor/rbush/rbush",
       gear_utils: "vendor/gear-utils/gear-utils",
       kiwi: "vendor/kiwi/kiwi",
       jsnlog: "vendor/jsnlog.js-2.7.5/jsnlog",
       hammer: "vendor/hammer.js-2.0.4/hammer",
-      numeral: "vendor/numeral.js-1.5.3/numeral"
+      numeral: "vendor/numeral.js-1.5.3/numeral",
+      handlebars: "vendor/handlebars-2.0.0/handlebars"
     },
     shim: {
-      sprintf: {
-        exports: 'sprintf'
-      },
       kiwi: {
         exports: 'kiwi'
-      },
-      jquery_event_drag: {
-        deps: ["jquery"],
-        exports: "$.fn.drag"
-      },
-      jquery_event_drop: {
-        deps: ["jquery"],
-        exports: "$.fn.drop"
       }
     }
   });
