@@ -1,9 +1,9 @@
 (function() {
   define(function(require, exports, module) {
-    var Bokeh, logging, _oldJQ;
+    var Bokeh, logging;
     Bokeh = {};
     Bokeh.require = require;
-    Bokeh.version = '0.8.1';
+    Bokeh.version = '0.8.2';
     Bokeh.index = require("common/base").index;
     logging = require("common/logging");
     Bokeh.logger = logging.logger;
@@ -13,13 +13,8 @@
       window.Float64Array = Array;
     }
     Bokeh._ = require("underscore");
-    Bokeh.$ = require("jquery");
+    Bokeh.$ = require("jquery-private");
     Bokeh.Backbone = require("backbone");
-    _oldJQ = window.$;
-    window.jQuery.noConflict();
-    if (typeof $ === "undefined") {
-      window.$ = _oldJQ;
-    }
     Bokeh.Collections = require("common/base").Collections;
     Bokeh.Config = require("common/base").Config;
     Bokeh.CartesianFrame = require("common/cartesian_frame");
