@@ -1,7 +1,6 @@
 from collections import OrderedDict
-import numpy as np
-import pandas as pd
-from bokeh.charts import Line
+
+from bokeh.charts import Line, show, output_file
 
 xyvalues = OrderedDict(
     python=[2, 3, 7, 5, 26, 221, 44, 233, 254, 265, 266, 267, 120, 111],
@@ -9,10 +8,13 @@ xyvalues = OrderedDict(
     jython=[22, 43, 10, 25, 26, 101, 114, 203, 194, 215, 201, 227, 139, 160],
 )
 
-# any of the following commented are valid Line inputs
+# any of the following commented are also valid Line inputs
 #xyvalues = pd.DataFrame(xyvalues)
 #xyvalues = xyvalues.values()
 #xyvalues = np.array(xyvalues.values())
 
-line = Line(xyvalues, title="Lines", ylabel='measures', filename="lines.html")
-line.xlabel('time').legend("top_left").show()
+output_file("lines.html", title="line.py example")
+
+chart = Line(xyvalues, title="Lines", ylabel='measures', legend=True)
+
+show(chart)
