@@ -6,8 +6,8 @@ import numpy as np
 from bokeh.browserlib import view
 from bokeh.document import Document
 from bokeh.embed import file_html
-from bokeh.glyphs import Line
-from bokeh.objects import (
+from bokeh.models.glyphs import Line
+from bokeh.models import (
     Plot, DataRange1d, LinearAxis, ColumnDataSource,
     PanTool, WheelZoomTool, PreviewSaveTool
 )
