@@ -20,7 +20,7 @@ from bokeh.models import (
     Range1d, DataRange1d,
     ColumnDataSource,
     LinearAxis, Grid,
-    PanTool, WheelZoomTool, ResetTool, BoxSelectTool, HoverTool)
+    PanTool, WheelZoomTool, ResetTool, BoxSelectTool)
 
 from bokeh.sampledata.mtb import obiszow_mtb_xcm
 
@@ -87,8 +87,7 @@ def trail_map(data):
     ygrid = Grid(plot=plot, dimension=1, ticker=yaxis.ticker, grid_line_dash="dashed", grid_line_color="gray")
     plot.renderers.extend([xgrid, ygrid])
 
-    hover = HoverTool(tooltips=[("distance", "@dist")])
-    plot.add_tools(hover, PanTool(), WheelZoomTool(), ResetTool(), BoxSelectTool())
+    plot.add_tools(PanTool(), WheelZoomTool(), ResetTool(), BoxSelectTool())
 
     line_source = ColumnDataSource(dict(x=data.lon, y=data.lat, dist=data.dist))
 
@@ -155,4 +154,4 @@ if __name__ == "__main__":
     with open(filename, "w") as f:
         f.write(file_html(doc, INLINE, "Trail map and altitude profile"))
     print("Wrote %s" % filename)
-    view(filename)
+    view(filename)
\ No newline at end of file
