@@ -27,4 +27,4 @@ p2 = figure(title="Categorical Heatmap", tools="resize,hover,save",
 
 p2.rect(x, y, color=colors, width=1, height=1)
 
-show(VBox(p1, p2))  # open a browser
+show(vplot(p1, p2))  # open a browser
