@@ -40,5 +40,5 @@ p2.yaxis.axis_label = 'Price'
 p2.ygrid.band_fill_color="olive"
 p2.ygrid.band_fill_alpha = 0.1
 
-show(VBox(p1,p2))  # open a browser
+show(vplot(p1,p2))  # open a browser
 
